@@ -25,17 +25,22 @@ class AbstractParser(abc.ABC):
 
         self.filename = filename
         fname, extension = os.path.splitext(filename)
+
+        # Special case for tar.gz, tar.bz2, … files
+        if fname.endswith('.tar') and len(fname) > 4:
+            fname, extension = fname[:-4], '.tar' + extension
+
         self.output_filename = fname + '.cleaned' + extension
         self.lightweight_cleaning = False
 
     @abc.abstractmethod
     def get_meta(self) -> Dict[str, Union[str, dict]]:
-        pass  # pragma: no cover
+        """Return all the metadata of the current file"""
 
     @abc.abstractmethod
     def remove_all(self) -> bool:
         """
+        Remove all the metadata of the current file
+
         :raises RuntimeError: Raised if the cleaning process went wrong.
         """
-        # pylint: disable=unnecessary-pass
-        pass  # pragma: no cover
